marktools.Articulation
======================

.. abjad-lineage:: abjad.tools.marktools.Articulation.Articulation.Articulation

.. autoclass:: abjad.tools.marktools.Articulation.Articulation.Articulation
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.marktools.Articulation.Articulation.Articulation.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.marktools.Articulation.Articulation.Articulation.start_component
   :noindex:

.. autoattribute:: abjad.tools.marktools.Articulation.Articulation.Articulation.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.marktools.Articulation.Articulation.Articulation.direction
   :noindex:

.. autoattribute:: abjad.tools.marktools.Articulation.Articulation.Articulation.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.attach
   :noindex:

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.detach
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__call__
   :noindex:

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__delattr__
   :noindex:

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__eq__
   :noindex:

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__ge__
   :noindex:

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__gt__
   :noindex:

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__le__
   :noindex:

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__lt__
   :noindex:

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__ne__
   :noindex:

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__repr__
   :noindex:

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__str__
   :noindex:
